# Copyright <2022> <Elizabeth Q Smith>
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
# OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.patches as mpatches
import time
import os

os.chdir('C:/Users/lizqs/Documents/Research Grad School/SSS data/Piankatank-2')

name = 'Oct26,2020,15-04-11.smb' #,'Oct26,2020,15-09-23.smb','Oct26,2020,15-15-20.smb','Oct26,2020,15-19-57.smb']
#rol_data = pd.DataFrame()

# Read in Data
string = "".join(['sonar_data', name, '.csv'])
sonar_data = pd.read_csv(string)
string2 = "".join(['settings', name, '.csv'])
settings = pd.read_csv(string2)

# initialize variables
num = 0
sett = np.arange(0,2000,1).tolist()
#get the dataframe for rolling std along each ping
for n in sett:


    line_dat = sonar_data.iloc[n, :]
    rol_data = line_dat.rolling(20,center=True, axis=0).std()
    rol_data = pd.DataFrame(rol_data)
    rol_data = rol_data.transpose()
    if num == 0:
        rol_data_along = rol_data
    else:
        rol_data_along = pd.concat([rol_data_along, rol_data], ignore_index=True)
    num = 1

# get the rolling std around the dataframe
sett = np.arange(0, len(sonar_data.iloc[7, :]), 1).tolist()
num = 0
for n in sett:

    line_dat = sonar_data.iloc[:, n]
    rol_data = line_dat.rolling(20,center=True,axis=0).std()
    rol_data = pd.DataFrame(rol_data)
    if num == 0:
        rol_data_around= rol_data
    else:
        rol_data[str(n)] = rol_data
        rol_data_around = rol_data_around.join(rol_data[str(n)])
    num = 1

# with pd.option_context('display.max_rows', None, 'display.max_columns', None):
#     print(rol_data_around)

num = 0
sett = np.arange(0, 2000, 1).tolist()
# get the dataframe for rolling std along and around each ping
for n in sett:

    line_dat = rol_data_around.iloc[n, :]
    rol_data = line_dat.rolling(20,center=True, axis=0).std()
    rol_data = pd.DataFrame(rol_data)
    rol_data = rol_data.transpose()
    if num == 0:
        rol_data_along_around = rol_data
    else:
        rol_data_along_around = pd.concat([rol_data_along_around, rol_data], ignore_index=True)
    num = 1

# Get theta, 1600 is 360/.225 #Assumed stepsize is .225
phi = np.arange(0,360,.225)
phi_ = np.radians(phi)

# Get range
range = settings.loc[0, 'Range']
spaces = len(rol_data_along.columns)
# create array of even steps...
r_ = np.arange(0, range, (range / spaces))

# method to plot as polar
r, phi = np.meshgrid(r_, phi_)
x_grid = r * np.cos(phi)
y_grid = r * np.sin(phi)

# gets the values for the data
rol_dat_al = rol_data_along.iloc[0:1600, :].to_numpy()
rol_dat_ar = rol_data_around.iloc[0:1600, :].to_numpy()
rol_dat_al_ar = rol_data_along_around.iloc[0:1600, :].to_numpy()

# gridlines for polar image
plot1 = plt.figure(1)
polarimg_al = plt.pcolormesh(x_grid, y_grid, rol_dat_al, vmin=0, vmax=200 )
string = "".join([name ,': Rolling standard deviation along pings'])
plt.title(string)
plt.ylabel('Range (m)')
plt.xlabel('Range (m)')

plot2 = plt.figure(2)
polarimg_ar = plt.pcolormesh(x_grid, y_grid, rol_dat_ar, vmin=0, vmax=200 )
string = "".join([name ,': Rolling standard deviation around center'])
plt.title(string)
plt.ylabel('Range (m)')
plt.xlabel('Range (m)')

plot3 = plt.figure(3)
polarimg_al_ar = plt.pcolormesh(x_grid, y_grid, rol_dat_al_ar, vmin=0, vmax=200 )
string = "".join([name ,': Rolling standard deviation around center and along pings'])
plt.title(string)
plt.ylabel('Range (m)')
plt.xlabel('Range (m)')
plt.show()