# Copyright <2022> <Elizabeth Q Smith>
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
# OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import math
import scipy.special as special
import scipy.integrate as integrate
import numpy as np
import pandas as pd
import cmath as c
import time
import os
import matplotlib.pyplot as plt
import matplotlib.patches as mpatches

# pull file
file_location = 'C:/Users/lizqs/Documents/Research Grad School'
os.chdir(file_location)
fid = 'Sonar_data_FULL_list.xlsx'
data = pd.read_excel(fid,index_col=None)

## filter data to get data wanted
data = data[data['Calc. Values']==2]
data = data[data['NOTE']!='BELOW CUTOFF LINE']
data = data[data['Roughness Description']!='Disturbed']

data = data[data['Roughness Description']!='Oysters']
#data = data[data['Roughness Description']!='Rocky']

# gain filters
data_dB40 = data[data['Decibels sent out (gain inputed) [dB]']==7.2]
data_dB90 = data[data['Is there 90% gain?']==1]

# range filters
data_dB90f = data_dB90[data_dB90['Distance away from sonar [m]']!=14]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=13]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=12]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=11]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=10]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=9]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=4]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=8]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=7]
data_dB90f = data_dB90f[data_dB90f['Distance away from sonar [m]']!=6]

## other filters
data_dB90f = data_dB90f[data_dB90f['Location']!='Piankatank']

# data_dB90f = data_dB90f[data_dB90f['Station']!=329]
#data_dB90f = data_dB90f[data_dB90f['USCS Classification']!='GW']


# data_dB90r6 = data_dB90[data_dB90['Distance away from sonar [m]']==6]
# data_dB40r5 = data_dB40[data_dB40['Distance away from sonar [m]']==5]
# data_dB40r6 = data_dB40[data_dB40['Distance away from sonar [m]']==6]

# Analyze according to fines content
# set with lower fines content
data_dB90f_sand = data_dB90f[data_dB90f['Fines Content [%]']<=20]
data_dB90f_fines = data_dB90f[data_dB90f['Fines Content [%]']>=60]


## import graphing
import plotly.express as px
import plotly.graph_objects as go

## TERNARY PLOT
# fig = px.scatter_ternary(tri_data, a='PFFP Qdynamic [kPa]', b='Water Content [%]', c= 'Mean Backscatter [dB]')
# fig.update_ternaries(aaxis=dict(color='black',gridcolor='black',linecolor='black',
#                                 tickfont=dict(size=30, family='Arial',color='black'),
#                                 title=dict(font=dict(size=30, color='black', family='Arial' ))),
#                      baxis = dict(color='black', gridcolor='black', linecolor='black',
#              tickfont=dict(size=30, family='Arial', color='Black'),
#              title=dict(font=dict(size=30, color='Black', family='Arial'))),
#                      caxis = dict(color='black', gridcolor='black', linecolor='black',
#              tickfont=dict(size=30, family='Arial', color='Black'),
#              title=dict(font=dict(size=30, color='Black', family='Arial'))),
#                      bgcolor='#FFF'
# )
# fig.update_traces(marker=dict(size=25,line=dict(width=2,
#                                     color='DarkSlateGrey')))
#

## SCATTER BUBBLE PLOT

# in order to plot as legend and not colorbar:
#data_dB90f_sand["Water Content [%]"] = data_dB90f_sand["Water Content [%]"].astype(str)
data_dB90f['Roughness Description'] = data_dB90f['Roughness Description'].astype(str)
data_dB90f['USCS Classification'] = data_dB90f['USCS Classification'].astype(str)
data_dB90f_sand['d50 [mm]'] = data_dB90f_sand['d50 [mm]'].astype(float)
data_dB90f_sand['Cc'] = data_dB90f_sand['Cc'].astype(float)

#fig = px.scatter(data_dB90f_fines, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', size='Water Content [%]', color='Water Content [%]')#,
                 #title='Scatter Plot of Water Content, Shear Strength, and Mean Side-Scan Sonar Backscatter for Sites with Greater Than 70% Fines Content') #,color='Distance away from sonar [m]')

fig = px.scatter(data_dB90f_sand, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', color='Water Content [%]',
                 labels={"PFFP Q dynamic at 8 cm [kPa]": "Sediment Strength [kPa]"}) #, trendline="ols") #, trendline_scope='trace')#,size='Water Content [%]'
#                  #title='Scatter Plot of Water Content, Shear Strength, and Mean Side-Scan Sonar Backscatter for Sites with Less Than 20% Fines Content') #,color='Distance away from sonar [m]')
# fig = px.scatter(data_dB90f_sand, x='Water Content [%]', y='Mean Backscatter [dB] (90% gain)', color='PFFP Q dynamic at 8 cm [kPa]',
#                  labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"}, color_continuous_scale='purples')

# fig = px.scatter(data_dB90f, x='Fines Content [%]', y='Mean Backscatter [dB] (90% gain)', color='Roughness Description') #, trendline="ewm")
# fig = px.scatter(data_dB90f, x='USCS Classification', y='Mean Backscatter [dB] (90% gain)', color='Roughness Description') #, trendline="ewm")
# , color_continuous_scale='algae'
# fig = px.scatter(data_dB90f_sand, x='Fines Content [%]', y='Mean Backscatter [dB] (90% gain)', color='Water Content [%]') #, trendline="ewm")
# fig = px.scatter(data_dB90f_sand, x='Fines Content [%]', y='Mean Backscatter [dB] (90% gain)', color='d50 [mm]') #, trendline="ewm")
# fig = px.scatter(data_dB90f_sand, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', color='d50 [mm]',
#                  labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"},color_continuous_scale='algae', trendline="ols") #, trendline="ewm")
# fig = px.scatter(data_dB90f_sand, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', color='Cc',
#                  #labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"}) #, trendline="ols")
# fig = px.scatter(data_dB90f_sand, x='d50 [mm]', y='Mean Backscatter [dB] (90% gain)', color='PFFP Q dynamic at 8 cm [kPa]',
#                  labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"}, color_continuous_scale='algae')

# fig = px.scatter(data_dB90f_sand, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', size='d50 [mm]', color='Roughness Description',
#                  labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"},color_continuous_scale='algae', trendline="ols")

# fig = px.scatter(data_dB90f_sand, x='Cc', y='Mean Backscatter [dB] (90% gain)', color='PFFP Q dynamic at 8 cm [kPa]',
#                 labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"}) #, trendline="ols")

# fig = px.scatter(data_dB90f, x='PFFP Q dynamic at 8 cm [kPa]', y='Mean Backscatter [dB] (90% gain)', color='Roughness Description',
#                  labels={"PFFP Q dynamic at 8 cm [kPa]": "Penetrometer Strength [kPa]"},color_continuous_scale='algae') #, trendline="ols")

# fig = px.scatter(data_dB90f, x='Fines Content [%]', y='Stan dev of section', color='Roughness Description')


# Formatting for Scatterplot
fig.update_layout(plot_bgcolor="#FFF",titlefont=dict(size=30),font_family="Arial",font_color="black",legend = dict(
    title_font_family="Arial",
    font=dict(family="Arial",size=30,color="black")),
    coloraxis_colorbar=dict(thickness=50,
    title_font=dict(size=30, family='Arial', color='black'),
    ticklabelposition="outside bottom",tickfont=dict(size=28))) # ticksuffix="%"
fig.update_xaxes(mirror=True, title_font=dict(size=30, family='Arial', color='black'),
                 tickfont=dict(family='Arial', color='black', size=30),
                 showline=True, linewidth=2, linecolor='black',showgrid=True, gridwidth=1, gridcolor='Black')
fig.update_yaxes(mirror=True, title_font=dict(size=30, family='Arial', color='black'),
                 tickfont=dict(family='Arial', color='black', size=30),
                 showline=True, linewidth=2, linecolor='black',showgrid=True, gridwidth=1, gridcolor='Black')
fig.update_traces(marker=dict(size=30, line=dict(width=2,color='DarkSlateGrey')))


fig.show()

# results = px.get_trendline_results(fig)
# print(results)
# print(results.px_fit_results.iloc[0].summary())
#

## OPTIONS FOR TITLE INPUTS
# 'PFFP deceleration at 8 cm'
# 'Stan dev of section',
# 'PFFP q_dyn at 8 cm (kPa)'
# 'Fines Content [%]'

## OTHER TYPES OF PLOTS
# fig = px.scatter_3d(data_dB90f_sand, x='WATER CONTENT [%]', y='FINES [%]', z='90% gain Mean dB') #,color='Distance away from sonar [m]')
# fig = px.density_contour(data_dB90r5, x='Section Description', y='FINES [%]', z='Mean of section', histfunc="avg")
# fig = px.scatter_matrix(data_dB90f_sand, dimensions=['Section Description','FINES [%]','Mean of section', 'd50 (mm)', 'PFFP q_dyn at 8 cm (kPa)', 'Cu', 'Cc','WATER CONTENT [%]'])#,color='Distance away from sonar [m]')
# fig = px.scatter_matrix(data_dB90f_fines, dimensions=['Section Description','FINES [%]','Mean of section', 'PI', 'PFFP q_dyn at 8 cm (kPa)'])







